# coding: utf-8
from django.db import models

class Store(models.Model):
    store = models.CharField('Provozovna', max_length=100)
    address = models.CharField('Adresa', max_length=100)
    city = models.CharField('Obec', max_length=100)
    postal_code = models.CharField('PSČ', max_length=10)
    email = models.EmailField('E-mail', blank=True)
    description = models.TextField('Popis', blank=True)

    def __unicode__(self):
        return self.store

    class Meta:
        verbose_name = 'provozovna'
        verbose_name_plural = 'provozovny'

FORMAT_CHOICES = (
    (0, 'Ostatní'),
    (1, 'VHS'),
    (2, 'DVD'),
    (3, 'Blu-ray'),
)

class Film(models.Model):
    store = models.ManyToManyField('Store')
    name_czech = models.CharField('Český název filmu', max_length=100)
    name_original = models.CharField('Původní název filmu', max_length=100, blank=True)
    year = models.PositiveIntegerField('Rok natočení')
    director = models.ForeignKey('Director', verbose_name='Režisér', null=True, blank=True)
    price = models.DecimalField('Cena za půjčení', max_digits=4, decimal_places=2, default=20)
    format = models.PositiveSmallIntegerField('Formát', choices=FORMAT_CHOICES)
    description = models.TextField('Popis', blank=True)
    added = models.DateTimeField('Čas přidání', auto_now_add=True)

    def __unicode__(self):
        return self.name_czech

    class Meta:
        ordering = ['name_czech']
        verbose_name = 'film'
        verbose_name_plural = 'filmy'

class Director(models.Model):
    name = models.CharField('Jméno a příjmení', max_length=100)

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = 'režisér'
        verbose_name_plural = 'režiséři'
